//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine science & computing) 
// September 2001
//
// $Id: OdfIcd.h,v 1.1.1.1 2004/05/20 13:50:06 eojero Exp $
//
#ifndef ODFICD_H
#define ODFICD_H

#include <Xmm.h>

#include <string>
#include<Observation.h>

namespace OdfIcd {

  // map instruments to two-letter identifiers (R1, M1 etc)
  std::string instrumentToString(const Xmm::Instrument& i);

  // map data modes to two-letter identifiers (IM, SP etc)
  std::string modeToString(const Xmm::DataMode& d);

  // given the revolution number, the observation identifier
  // (10-characters), the instrument, and the mode, return the
  // corresponding housekeeping file name. Example:
  //    hkname(123, '0123456789', Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1) =
  //    0123_0123456789_R1X00000D1H.FIT
  // The function has no notion of whether a given data mode is an
  // housekeeping mode.
  std::string hkname(unsigned revolution, const std::string & observation,
		     Xmm::Instrument i, Xmm::DataMode d);

  // as above, but take an integer observation identifier
  std::string hkname(unsigned revolution, unsigned observation,
		     Xmm::Instrument i, Xmm::DataMode d);

  // as above, but take a pointer to an exposure
  std::string hkname(const OdfIngest::Exposure & e, Xmm::DataMode d);


}


#endif
