//  Giuseppe Vacanti (cosine science & computing bv)
//  March 10, 2003
//
//   $Id: HkparameterTest.cc,v 1.2 2009/08/31 15:12:34 aibarra Exp $

#include<iostream>
#include<Hkparameter.h>
#include<Hkparameter_Descriptor.h>
#include<SmartDal>
#include<TimeRows.h>

static Hkparameter_Descriptor id_per = {
  (char*) "i32Param",
  (char *) "i32Column",
  (char *) "TRUE",
  (char *) "no description",
  Dal::Int32,
  Xmm::RGS1,
  Xmm::PERIODIC_HOUSEKEEPING,
  true
};

// static Hkparameter_Descriptor id_nper = {
//   "u16Param",
//   "u16Column",
//   "TRUE",
//   "no description",
//   Dal::Uint16,
//   Xmm::RGS1,
//   Xmm::PERIODIC_HOUSEKEEPING,
//   true
// };


void create_test_set(const std::string & name, unsigned long rows = 100)
{
  using namespace SmartDal;

  DataSetH set = open_set(name,Create);
  TableH tab = set->addTable("some_table",rows);
  tab->addColumn("boolColumn",Dal::Bool,"","");
  tab->addColumn("i8Column",Dal::Int8,"","");
  tab->addColumn("u16Column",Dal::Uint16,"","");
  tab->addColumn("i16Column",Dal::Int16,"","");
  tab->addColumn("u32Column",Dal::Uint32,"","");
  tab->addColumn("i32Column",Dal::Int32,"","");
  tab->addColumn("r32Column",Dal::Real32,"","");
  tab->addColumn("r64Column",Dal::Real64,"","");

  longVec d(1,19);
  tab->addColumn("strColumn",Dal::DString,"","", d);
  tab->addColumn("TIME",Dal::DString,"","", d);

  {
    ColumnH c = tab->column("i32Column");
    ColumnDataH cd = c->data();
    int32 * cv = cd->int32Data();
    for(unsigned k = 0; k < cd->parent()->rows(); ++k)
      cv[k] = 2*k;
  }


  {
    ColumnH c = tab->column("TIME");
    STime t("now");
    double step = 8.;
    for(unsigned k = 0; k < c->parent()->rows(); ++k)
      set_string_row(c, k, (t + step *k).toString(0));
  }
}

template<typename T> void constant_rows(const std::string & name,
				   unsigned from, unsigned count, T value){
  using namespace SmartDal;
  DataSetH set = open_set(name, Modify);
  TableH table = set->table(name);
  assert(table->rows() > from);
  assert(table->rows() > from + count);

  ColumnH column = table->column(name);
  ColumnDataH data = column->data();
  T * v = data->Data::data<T>();
  for(unsigned k = 0; k < count; ++k)
    v[from + k] = value;
}

int main() {

  using namespace SmartDal;
  const std::string name = "HkparameterTest.ds";
  const unsigned long rows = 100;
  Hkparameter * hkp = Hkparameter::make(id_per, 0);
  create_test_set(name, rows);
  constant_rows(name + "::" + hkp->colname(), 16, 30, 5);
  DataSetH set = open_set(name, Read);
  TableH tab = set->table(0);
  TimeRows tr(tab);
  STime t("now");
//   unsigned low = tr.lower_bound(t+120.);
//   unsigned upp = tr.upper_bound(t+360.);
//   std::cout << "Seek range: " << low << " " << upp << std::endl;

//   tab->seek(low,upp - low);

  hkp->process(tab, t + 120., t + 360.);
  std::cout << hkp->value() << std::endl;

//   int32 * v = chkd->data<int32>();
//   for(unsigned l = 0 ; l < chk->count(); ++l)
//     std::cout << l << " " << v[l] << std::endl;

}

